@@ -9,8 +9,13 @@ import pkg_resources
 
 
 def prinfPath():
-    print("!!!" + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
+    print("path is " + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
 
+def prinfPathOS:
+    print(os.path.dirname(os.path.realpath(__file__)))
+
+def prinfPathABC():
+    print("ABCDEFG")
 
 #打码函数
 # size为打码的方块大小
